@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Time::HiRes;
 use 5.008001;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub new {
     my ($class) = @_;
@@ -51,6 +51,12 @@ sub delete :method {
     delete $self->{$key};
 }
 
+sub delete_all {
+    my $self = shift;
+    delete $self->{$_} for keys %$self;
+    return;
+}
+
 sub purge {
     my $self = shift;
     for my $key (keys %{$self}) {
@@ -121,6 +127,10 @@ Purge expired data.
 
 This module does not purge expired data automatically. You need to call this method if you need.
 
+=item $obj->delete_all()
+
+Remove all data from cache.
+
 =back
 
 =head1 AUTHOR
